.. _spkg_idna:

idna: Internationalized Domain Names in Applications (IDNA)
===========================================================

Description
-----------

Internationalized Domain Names in Applications (IDNA)

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/idna/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    3.10

version_requirements.txt::

    idna

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install idna

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i idna

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-idna

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install idna

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install python3-idna

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-idna

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/idna

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-idna

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3-idna

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-idna


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
